@@ -139,6 +139,8 @@ g_io_error_get_from_g_error (GIOStatus status,
       case G_IO_STATUS_AGAIN:
         return G_IO_ERROR_AGAIN;
       case G_IO_STATUS_ERROR:
+	g_return_val_if_fail (err != NULL, G_IO_ERROR_UNKNOWN);
+	
         if (err->domain != G_IO_CHANNEL_ERROR)
           return G_IO_ERROR_UNKNOWN;
         switch (err->code)
@@ -536,9 +538,6 @@ g_io_channel_error_from_errno (gint en)
 #ifdef EAGAIN
   g_return_val_if_fail (en != EAGAIN, G_IO_CHANNEL_ERROR_FAILED);
 #endif
-#ifdef EINTR
-  g_return_val_if_fail (en != EINTR, G_IO_CHANNEL_ERROR_FAILED);
-#endif
 
   switch (en)
     {
@@ -559,6 +558,18 @@ g_io_channel_error_from_errno (gint en)
       return G_IO_CHANNEL_ERROR_FBIG;
 #endif
 
+#ifdef EINTR
+    /* In general, we should catch EINTR before we get here,
+     * but close() is allowed to return EINTR by POSIX, so
+     * we need to catch it here; EINTR from close() is
+     * unrecoverable, because it's undefined whether
+     * the fd was actually closed or not, so we just return
+     * a generic error code.
+     */
+    case EINTR:
+      return G_IO_CHANNEL_ERROR_FAILED;
+#endif
+
 #ifdef EINVAL
     case EINVAL:
       return G_IO_CHANNEL_ERROR_INVAL;
@@ -1635,8 +1646,8 @@ done:
  *
  * Reads all the remaining data from the file.
  *
- * Return value: %G_IO_STATUS_NORMAL on success. This function never
- *               returns %G_IO_STATUS_EOF.
+ * Return value: %G_IO_STATUS_NORMAL on success. 
+ * This function never returns %G_IO_STATUS_EOF.
  **/
 GIOStatus
 g_io_channel_read_to_end (GIOChannel	*channel,
