@@ -272,6 +272,11 @@ g_poll (GPollFD *fds,
       {
 	if (f->fd == G_WIN32_MSG_HANDLE)
 	  poll_msgs = TRUE;
+	else if (nhandles == MAXIMUM_WAIT_OBJECTS)
+	  {
+	    g_warning (G_STRLOC ": Too many handles to wait for!\n");
+	    break;
+	  }
 	else
 	  {
 #ifdef G_MAIN_POLL_DEBUG
@@ -547,6 +552,26 @@ g_main_context_ref (GMainContext *context)
   UNLOCK_CONTEXT (context);
 }
 
+/* If DISABLE_MEM_POOLS is defined, then freeing the
+ * mem chunk won't free the records, so we have to
+ * do it manually. The conditionalization here is
+ * an optimization; g_mem_chunk_free() is a no-op
+ * when DISABLE_MEM_POOLS is set.
+ */
+#ifdef DISABLE_MEM_POOLS
+static void
+poll_rec_list_free (GMainContext *context,
+		    GPollRec     *list)
+{
+  while (list)
+    {
+      GPollRec *tmp_rec = list;
+      list = list->next;
+      g_chunk_free (tmp_rec, context->poll_chunk);
+    }
+}
+#endif /* DISABLE_MEM_POOLS */
+
 static void
 g_main_context_unref_and_unlock (GMainContext *context)
 {
@@ -576,7 +601,13 @@ g_main_context_unref_and_unlock (GMainContext *context)
   g_ptr_array_free (context->pending_dispatches, TRUE);
   g_free (context->cached_poll_array);
   
-  g_mem_chunk_destroy (context->poll_chunk);
+#ifdef DISABLE_MEM_POLLS
+  poll_rec_list_free (context, context->poll_records);
+  poll_rec_list_free (context, context->poll_free_list);
+#endif /* DISABLE_MEM_POOLS */
+   
+  if (context->poll_chunk)
+    g_mem_chunk_destroy (context->poll_chunk);
 
 #ifdef G_THREADS_ENABLED
   if (g_thread_supported())
