@@ -497,7 +497,8 @@ g_logv (const gchar   *log_domain,
 #ifdef G_OS_WIN32
 	      gchar *locale_msg = g_locale_from_utf8 (fatal_msg_buf, -1, NULL, NULL, NULL);
 	      
-	      MessageBox (NULL, locale_msg, NULL, MB_OK);
+	      MessageBox (NULL, locale_msg, NULL,
+			  MB_ICONERROR|MB_SETFOREGROUND);
 #endif
 #if defined (G_ENABLE_DEBUG) && (defined (SIGTRAP) || defined (G_OS_WIN32))
 	      if (!(test_level & G_LOG_FLAG_RECURSION))
@@ -766,7 +767,7 @@ g_log_default_handler (const gchar   *log_domain,
 
   fd = mklevel_prefix (level_prefix, log_level);
 
-  gstring = g_string_new ("");
+  gstring = g_string_new (NULL);
   if (log_level & ALERT_LEVELS)
     g_string_append (gstring, "\n");
   if (!log_domain)
