@@ -18,6 +18,8 @@
  *   Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
+
 #include <locale.h>
 #include <string.h>
 #ifdef __STDC_ISO_10646__
@@ -53,8 +55,14 @@ g_utf8_collate (const gchar *str1,
   
 #ifdef __STDC_ISO_10646__
 
-  gunichar *str1_norm = _g_utf8_normalize_wc (str1, -1, G_NORMALIZE_ALL_COMPOSE);
-  gunichar *str2_norm = _g_utf8_normalize_wc (str2, -1, G_NORMALIZE_ALL_COMPOSE);
+  gunichar *str1_norm;
+  gunichar *str2_norm;
+
+  g_return_val_if_fail (str1 != NULL, 0);
+  g_return_val_if_fail (str2 != NULL, 0);
+
+  str1_norm = _g_utf8_normalize_wc (str1, -1, G_NORMALIZE_ALL_COMPOSE);
+  str2_norm = _g_utf8_normalize_wc (str2, -1, G_NORMALIZE_ALL_COMPOSE);
 
   result = wcscoll ((wchar_t *)str1_norm, (wchar_t *)str2_norm);
 
@@ -64,8 +72,14 @@ g_utf8_collate (const gchar *str1,
 #else /* !__STDC_ISO_10646__ */
 
   const gchar *charset;
-  gchar *str1_norm = g_utf8_normalize (str1, -1, G_NORMALIZE_ALL_COMPOSE);
-  gchar *str2_norm = g_utf8_normalize (str2, -1, G_NORMALIZE_ALL_COMPOSE);
+  gchar *str1_norm;
+  gchar *str2_norm;
+
+  g_return_val_if_fail (str1 != NULL, 0);
+  g_return_val_if_fail (str2 != NULL, 0);
+
+  str1_norm = g_utf8_normalize (str1, -1, G_NORMALIZE_ALL_COMPOSE);
+  str2_norm = g_utf8_normalize (str2, -1, G_NORMALIZE_ALL_COMPOSE);
 
   if (g_get_charset (&charset))
     {
@@ -169,11 +183,15 @@ g_utf8_collate_key (const gchar *str,
   
 #ifdef __STDC_ISO_10646__
 
-  gunichar *str_norm = _g_utf8_normalize_wc (str, len, G_NORMALIZE_ALL_COMPOSE);
+  gunichar *str_norm;
   wchar_t *result_wc;
   size_t i;
   size_t result_len = 0;
 
+  g_return_val_if_fail (str != NULL, NULL);
+
+  str_norm = _g_utf8_normalize_wc (str, len, G_NORMALIZE_ALL_COMPOSE);
+
   setlocale (LC_COLLATE, "");
 
   xfrm_len = wcsxfrm (NULL, (wchar_t *)str_norm, 0);
@@ -197,7 +215,11 @@ g_utf8_collate_key (const gchar *str,
 #else /* !__STDC_ISO_10646__ */
 
   const gchar *charset;
-  gchar *str_norm = g_utf8_normalize (str, len, G_NORMALIZE_ALL_COMPOSE);
+  gchar *str_norm;
+
+  g_return_val_if_fail (str != NULL, NULL);
+
+  str_norm = g_utf8_normalize (str, len, G_NORMALIZE_ALL_COMPOSE);
 
   if (g_get_charset (&charset))
     {
