@@ -30,7 +30,8 @@ extern "C" {
    The result must not be freed; it is statically allocated.
    If the canonical name cannot be determined, the result is a non-canonical
    name.  */
-extern const char * _g_locale_charset (void);
+extern const char * _g_locale_charset_raw (void);
+extern const char * _g_locale_charset_unalias (const char *codeset);
 extern const char * _g_locale_get_charset_aliases (void);
 
 #ifdef __cplusplus
