@@ -9,6 +9,9 @@ fail ()
 for I in $srcdir/markups/fail-*.gmarkup; do
   echo "Parsing $I, should fail"
   ./markup-test $I > /dev/null && fail "failed to generate error on $I"
+  if test "$?" != "1"; then
+    fail "unexpected error on $I"
+  fi  
 done
 
 for I in $srcdir/markups/valid-*.gmarkup; do
